<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################



# Posizione delle cartelle "dati" e "scontri" rispetto alla cartella di fantacalciobazar. 
# Cambiare SOLO SE queste cartelle non si trovano nella stessa cartella degli alti file 
# di fantacalciobazar! Non mettere lo slash alla fine. La cartella "voti" è dove vengono 
# posizionati i file votiXX.txt e calciatori.txt, di default la stessa "dati".
$percorso_cartella_dati = "./dati";
$percorso_cartella_scontri = "./scontri";
$percorso_cartella_voti = $percorso_cartella_dati;


include("$percorso_cartella_dati/dati.php");
$pass_admin_errata = "SI";
if ($nome_utente == "admin") {
$pass_errata = "SI";
if ($passadmin == "nopasswordinserita") { $password = ""; }
else { $password = $passadmin; }
if ($pass_fornita == $password) {
$pass_admin_errata = "NO";
} # fine if ($pass_fornita == $password)
} # fine if ($nome_utente == "admin")
else {
if (!$pass[$nome_utente]) {
$pass_errata = "SI";
} # fine if (!$pass[$nome_utente])
if ($pass[$nome_utente] == "nopasswordinserita") { $password = ""; }
else { $password = $pass[$nome_utente]; }
if ($pass_fornita != $password) {
$pass_errata = "SI";
} # fine if ($pass_fornita != $password)
if ($parla != "NO" and $pass_errata == "SI") echo "Nome utente o password errati.<br>";
} # fine else if ($nome_utente == "admin")

?>
